@@ -12,7 +12,7 @@ use warnings;
 
 package CPANPLUS::Dist::Mageia;
 # ABSTRACT: a cpanplus backend to build mageia rpms
-$CPANPLUS::Dist::Mageia::VERSION = '2.101';
+$CPANPLUS::Dist::Mageia::VERSION = '2.102';
 use base 'CPANPLUS::Dist::Base';
 
 use CPANPLUS::Error; # imported subs: error(), msg()
@@ -72,7 +72,7 @@ sub init {
     my $status = $self->status; # an Object::Accessor
     # distname: Foo-Bar
     # distvers: 1.23
-    # extra_files: qw[ /bin/foo /usr/bin/bar ] 
+    # extra_files: qw[ /bin/foo /usr/bin/bar ]
     # rpmname:  perl-Foo-Bar
     # rpmpath:  $RPMDIR/RPMS/noarch/perl-Foo-Bar-1.23-1mga2008.0.noarch.rpm
     # rpmvers:  1
@@ -125,12 +125,15 @@ sub prepare {
         $distinstall = "%makeinstall_std";
     } else {
         # module::build only distribution
+        # The double dashes ("--") are for Module::Build::Tiny compatibility:
+        #   * https://rt.cpan.org/Ticket/Display.html?id=86240
+        #   * https://wiki.mageia.org/en/Perl_policy
         push @reqs, 'Module::Build';
         $distbuild = "%{__perl} Build.PL --installdirs=vendor\n";
         $distmaker = "./Build";
         $distinstall = "./Build install --destdir=%{buildroot}";
     }
-    my $distbreqs      = join "\n", map { "BuildRequires: perl($_)" } 
+    my $distbreqs      = join "\n", map { "BuildRequires: perl($_)" }
                          grep { $_ ne "perl" } @reqs;
     my @docfiles =
         uniq
@@ -356,7 +359,7 @@ sub install {
 # my $bool = $self->_has_been_build;
 #
 # return true if there's already a package build for this module.
-# 
+#
 sub _has_been_build {
     my ($self, $name, $vers) = @_;
     my $pkg = ( sort glob "$RPMDIR{rpm}/*/$name-$vers-*.rpm" )[-1];
@@ -521,7 +524,7 @@ CPANPLUS::Dist::Mageia - a cpanplus backend to build mageia rpms
 
 =head1 VERSION
 
-version 2.101
+version 2.102
 
 =head1 DESCRIPTION
 
@@ -603,7 +606,7 @@ Returns true on success and false on failure
 =head2 Scan for proper license
 
 Right now we assume that the license of every module is C<the same
-as perl itself>. Although correct in almost all cases, it should 
+as perl itself>. Although correct in almost all cases, it should
 really be probed rather than assumed.
 
 =head2 Long description
@@ -622,9 +625,9 @@ You can look for information on this module at:
 
 =over 4
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/CPANPLUS-Dist-Mageia>
+L<http://metacpan.org/release/CPANPLUS-Dist-Mageia>
 
 =item * See open / report bugs
 
